@@ -15,13 +15,13 @@
 #'
 #' data(daxreturns)
 #'
-#' data <- as(daxreturns, "matrix")
+#' data <- as.matrix(daxreturns)
 #' class(as.copuladata(data))
 #'
-#' data <- as(daxreturns, "data.frame")
+#' data <- as.data.frame(daxreturns)
 #' class(as.copuladata(data))
 #'
-#' data <- as(daxreturns, "list")
+#' data <- as.list(daxreturns)
 #' names(data) <- names(daxreturns)
 #' class(as.copuladata(data))
 #'
@@ -32,9 +32,9 @@ as.copuladata <- function(data) {
 
 as.copuladata.data.frame <- function(data) {
     ## coercion of 'data.frame' to 'copuladata'
-    if (any(sapply(data, mode) != "numeric"))
+    if (!all(sapply(data, is.numeric)))
         stop("Data has to be numeric.")
-    if (any(data > 1 || data < 0))
+    if (any(data > 1 | data < 0))
         stop("Data has to be in the interval [0,1].")
     class(data) <- append("copuladata", class(data))
     return(data)
@@ -42,9 +42,9 @@ as.copuladata.data.frame <- function(data) {
 
 as.copuladata.matrix <- function(data) {
     ## coercion of 'matrix' to 'copuladata'
-    if (mode(data) != "numeric")
+    if (!all(is.numeric(data)))
         stop("Data has to be numeric.")
-    if (any(data > 1 || data < 0))
+    if (any(data > 1 | data < 0))
         stop("Data has to be in the interval [0,1].")
     data <- data.frame(data)
     class(data) <- append("copuladata", class(data))
@@ -53,12 +53,12 @@ as.copuladata.matrix <- function(data) {
 
 as.copuladata.list <- function(data) {
     ## coercion of 'list' to 'copuladata'
-    if (any(sapply(data, mode) != "numeric"))
+    if (!all(sapply(data, is.numeric)))
         stop("Data has to be numeric.")
     if (any(sapply(data, length) != length(data[[1]])))
         stop("All list entries have to be of same length.")
     data <- data.frame(data)
-    if (any(data > 1 || data < 0))
+    if (any(data > 1 | data < 0))
         stop("Data has to be in the interval [0,1].")
     class(data) <- append("copuladata", class(data))
     return(data)
